@@ -22,9 +22,9 @@ int main(int argc, char *argv[])
 
     if (argc < 2)
     {
-	printf("french-deconjugator-c demo for the C api of libverbiste\n");
-	printf("Usage: french-deconjugator-c word\n");
-	return 1;
+	printf("deconjugator.c: demo of the C API of Verbiste\n");
+	printf("Usage: deconjugator VERB\n");
+	return EXIT_FAILURE;
     }
 
 
@@ -35,7 +35,7 @@ int main(int argc, char *argv[])
     if (vec == NULL) 
     {        
 	fprintf(stderr, "Internal error in libverbiste.\n");
-	return 1;
+	return EXIT_FAILURE;
     }
 
 
@@ -54,5 +54,5 @@ int main(int argc, char *argv[])
 
     verbiste_close();
 
-    return 0;
+    return EXIT_SUCCESS;
 }
