@@ -1,8 +1,8 @@
-/*  $Id: Command.cpp,v 1.9 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: Command.cpp,v 1.11 2006/07/08 19:20:05 sarrazip Exp $
     Command.cpp - Abstract command-line driver
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,9 +31,10 @@ using namespace verbiste;
 namespace verbiste {
 
 
-Command::Command() throw (logic_error)
+Command::Command(bool _utf8Mode) throw (logic_error)
+  : fvd(new FrenchVerbDictionary()),
+    utf8Mode(_utf8Mode)
 {
-    fvd = new FrenchVerbDictionary();
 }
 
 
@@ -56,24 +57,41 @@ Command::run(int argc, char *argv[]) throw()
 
 	for (;;)
 	{
-	    string latin1InputWord;
+	    string inputWord;
 
 	    if (useArgs)
 	    {
 		if (optind == argc)
 		    break;
 
-		latin1InputWord = argv[optind];
+		inputWord = argv[optind];
 		optind++;
 	    }
 	    else
 	    {
-		if (!getline(cin, latin1InputWord))
+		if (!getline(cin, inputWord))
 		    break;
 	    }
 
 
-	    // Source is assumed to be in ISO-8859-1; convert it to lower-case.
+	    string latin1InputWord;
+	    if (utf8Mode)
+	    {
+		try
+		{
+		    latin1InputWord = fvd->utf8ToLatin1(inputWord);
+		}
+		catch (int)
+		{
+		    // Conversion failed. Leave latin1InputWord empty.
+		}
+	    }
+	    else
+	    {
+		// Source is assumed to be in ISO-8859-1:
+		latin1InputWord = inputWord;
+	    }
+
 	    processInputWord(fvd->tolowerLatin1(latin1InputWord));
 	}
     }
