@@ -1,8 +1,8 @@
-/*  $Id: Command.h,v 1.7 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: Command.h,v 1.9 2006/07/08 19:20:05 sarrazip Exp $
     Command.h - Abstract command-line driver
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -47,11 +47,14 @@ class Command
 public:
 
     /** Initializes the command object and the Verbiste dictionary.
+	@param	utf8Mode		indicates if the terminal and
+					command line should be assumed to be
+					encoded in UTF-8 (instead of Latin-1)
 	@throws	std::logic_error	error message related to a failure to
 					construct the FrenchVerbDictionary
 					object
     */
-    Command() throw (std::logic_error);
+    Command(bool utf8Mode) throw (std::logic_error);
 
     /** Destroys the Verbiste dictionary object.
     */
@@ -91,10 +94,15 @@ protected:
     virtual void processInputWord(const std::string &inputWord) = 0;
 
 
-    /**
-	Instance of the Verbiste dictionary to use to process the words.
+    /** Instance of the Verbiste dictionary to use to process the words.
     */
     FrenchVerbDictionary *fvd;
+
+
+    /** Indication of encoding used by terminal and command line.
+	If false, then Latin-1 (ISO-8859-1) is assumed.
+    */
+    bool utf8Mode;
 };
 
 
